@@ -2,7 +2,7 @@ __author__ = "Jonas Geduldig"
 __date__ = "June 7, 2013"
 __license__ = "MIT"
 
-import constants
+from .constants import *
 import json
 import requests
 from requests_oauthlib import OAuth1
@@ -18,23 +18,23 @@ class TwitterAPI(object):
 	def __init__(self, consumer_key, consumer_secret, access_token_key, access_token_secret):
 		self.session = requests.Session() 
 		self.session.auth = OAuth1(consumer_key, consumer_secret, access_token_key, access_token_secret)
-		self.session.headers = {'User-Agent':constants.USER_AGENT}
+		self.session.headers = {'User-Agent':USER_AGENT}
 		
 	def _make_url(self, subdomain, path):
-		return '%s://%s.%s/%s/%s' % (constants.PROTOCOL, subdomain, constants.DOMAIN, constants.VERSION, path)
+		return '%s://%s.%s/%s/%s' % (PROTOCOL, subdomain, DOMAIN, VERSION, path)
 		
 	def _rest_request(self, resource, params=None):
-		method = constants.REST_ENDPOINTS[resource][0]
-		url = self._make_url(constants.REST_SUBDOMAIN, resource + '.json')
+		method = REST_ENDPOINTS[resource][0]
+		url = self._make_url(REST_SUBDOMAIN, resource + '.json')
 		self.session.stream = False
-		self.response = self.session.request(method, url, params=params, timeout=constants.REST_SOCKET_TIMEOUT)
+		self.response = self.session.request(method, url, params=params, timeout=REST_SOCKET_TIMEOUT)
 		return self.response
 		
 	def _streaming_request(self, resource, params=None):
 		method = 'GET' if params is None else 'POST'
-		url = self._make_url(constants.STREAMING_ENDPOINTS[resource][0], resource + '.json')
+		url = self._make_url(STREAMING_ENDPOINTS[resource][0], resource + '.json')
 		self.session.stream = True
-		self.response = self.session.request(method, url, params=params, timeout=constants.STREAMING_SOCKET_TIMEOUT)
+		self.response = self.session.request(method, url, params=params, timeout=STREAMING_SOCKET_TIMEOUT)
 		return self.response
 		
 	def request(self, resource, params=None):
@@ -45,9 +45,9 @@ class TwitterAPI(object):
 		
 		Returns a response object from the requests module.  
 		"""
-		if resource in constants.REST_ENDPOINTS:
+		if resource in REST_ENDPOINTS:
 			return self._rest_request(resource, params)
-		elif resource in constants.STREAMING_ENDPOINTS:
+		elif resource in STREAMING_ENDPOINTS:
 			return self._streaming_request(resource, params)
 		else:
 			raise Exception('"%s" is not valid endpoint' % resource)
